@@ -60,7 +60,8 @@ class SequentialBpmnEngineTest(unittest.TestCase):
         engine = SequentialBpmnEngine()
         ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/call_activity.bpmn")[0]
 
-        state = engine.invoke_by_id(ref, {"x": 5})
+        engine.invoke_by_id(ref, {"x": 5}, {"id": 123})
+        state = engine.invoke_by_event(ManualEvent("customGroup", "subprocess", "task2", {}))[0]
         self.assertAlmostEqual(state["y1"], 7.5)
         self.assertAlmostEqual(state["y2"], 15)
 
@@ -152,4 +153,4 @@ class SequentialBpmnEngineTest(unittest.TestCase):
         ref = engine.deploy("customGroup", Path(__file__).parent / "diagrams/http_task.bpmn")[0]
 
         state = engine.invoke_by_id(ref)
-        self.assertEqual(state["result"], "Luke Skywalker")
\ No newline at end of file
+        self.assertEqual(state["result"], "Luke Skywalker")
