@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from typing import Optional
 
 from arrow_bpmn.__spi__.action import Action
 
@@ -7,3 +8,4 @@ from arrow_bpmn.__spi__.action import Action
 class IncidentAction(Action):
     id: str
     error_ref: str
+    error_msg: Optional[str] = None
