@@ -66,5 +66,10 @@ class Environment:
             return "StartEvent" in type(self.nodes[node_id]).__name__
         return False
 
+    def is_end_event(self, node_id: str) -> bool:
+        if node_id in self.nodes:
+            return "EndEvent" in type(self.nodes[node_id]).__name__
+        return False
+
     def get_message(self, message_ref: str):
         return self.event_specs.messages[message_ref]
