@@ -22,7 +22,7 @@ class State:
     def with_parent_reference(self, parent_reference: Optional[NodeRef]):
         return State(self.properties, self.node_ref, self.is_reentry, parent_reference, self.header)
 
-    def with_reference(self, reference: NodeRef):
+    def with_node_ref(self, reference: NodeRef):
         return State(self.properties, reference, self.is_reentry, self.parent_reference, self.header)
 
     def __setitem__(self, key, value):
