@@ -15,3 +15,5 @@ class LoggingIncidentHandler(IncidentHandler):
     def handle(self, action: IncidentAction):
         import logging
         logging.error(action.error_ref)
+        if action.error_msg is not None:
+            logging.error(action.error_msg)
