@@ -31,3 +31,6 @@ class NodeRef(ProcessRef):
         if self.process_instance_id is not None and self.node_instance_id is not None:
             return self.group + ":" + self.process_id + ":" + self.node_id + ":" + self.process_instance_id + ":" + self.node_instance_id
         return self.group + ":" + self.process_id + ":" + self.node_id
+
+    def __iter__(self):
+        return iter((self.group, self.process_id, self.node_id, self.process_instance_id, self.node_instance_id))
