@@ -34,7 +34,7 @@ class SequentialBpmnEngine(BpmnEngine):
             environment = Environment(event.group, process, self.factories)
 
             if environment.is_start_event(node_ref.node_id):
-                state = State(init_state or {}, node_ref, header=header)
+                state = State(init_state or {}, node_ref, header=header or {})
                 return self._handle_action(ContinueAction(node_ref.node_id), state, environment)
             return []
 
@@ -50,7 +50,7 @@ class SequentialBpmnEngine(BpmnEngine):
             if not environment.is_start_event(node_ref.node_id):
                 new_state = self.process_store.read_state(node_ref)
                 new_state.properties.update(state or {})
-                new_state.header = header
+                new_state.header.update(header or {})
                 new_state.is_reentry = is_reentry
 
                 action = ContinueAction(node_ref.node_id)
@@ -66,19 +66,19 @@ class SequentialBpmnEngine(BpmnEngine):
         assert len(states) > 0, "error while invoking process"
         return states[0]
 
+    # noinspection DuplicatedCode
     def _handle_action(self, action: Action, state: State, env: Environment) -> List[State]:
-        action, state, env = self.interceptor(action, state, env)
-
         logging.info(action)
+        [listener.on_action(action, state, env) for listener in self.listeners]
 
         # Continue Action
         # ***************
         if isinstance(action, ContinueAction):
-            node = self.interceptor.intercept_node(env.get_node(action.id))
+            node = self.interceptor(env.get_node(action.id))
             assert node is not None, f"no node found with id {action.id}"
 
             node_ref = NodeRef(env.group, state.node_ref.process_id, action.id, str(uuid.uuid4()), str(uuid.uuid4()))
-            new_state = state.with_reference(node_ref)
+            new_state = state.with_node_ref(node_ref)
 
             # execute all present boundary events in order to register their events
             [self._handle_action(ContinueAction(e.id), state, env) for e in env.get_boundary_events(node.id)]
@@ -99,6 +99,10 @@ class SequentialBpmnEngine(BpmnEngine):
             if action.save_state:
                 self.process_store.write_state(state)
 
+            if env.is_end_event(action.id):
+                if state.parent_reference is not None:
+                    return self._handle_action(ResumeAction(state.parent_reference), state, env)
+
             if action.consume_token:
                 return [state]
 
@@ -132,28 +136,27 @@ class SequentialBpmnEngine(BpmnEngine):
             subscription = first(self.event_registry.get_subscriptions(event))
 
             process = self.process_store.read_process(ProcessRef(event.group, subscription.process_id))
-            new_state = State(action.init_state, subscription, False, action.parent_reference)
+            new_state = State(action.init_state, subscription, False, action.parent_reference, state.header)
             new_environment = Environment(event.group, process, self.factories)
 
             new_state = first(self._handle_action(ContinueAction(subscription.node_id), new_state, new_environment))
-            return self._handle_action(ResumeAction(new_state.parent_reference), new_state, env)
+            return [new_state]
 
         # Resume Action
         # *************
         elif isinstance(action, ResumeAction):
-            _env = env
-            if action.reference.process_id != env.process_id:
-                parent_process = self.process_store.read_process(ProcessRef(env.group, action.reference.process_id))
-                _env = Environment(env.group, parent_process, self.factories)
+            parent_process = self.process_store.read_process(ProcessRef(env.group, action.reference.process_id))
+            next_env = Environment(env.group, parent_process, self.factories)
+            next_state = State(state.properties, action.reference, True, None, state.header)
 
-            node = _env.get_node(action.reference.node_id)
+            node = next_env.get_node(action.reference.node_id)
             assert node is not None, f"no node found with id {action.reference.node_id}"
 
-            [x.before_node_execution(node) for x in self.listeners]
-            new_state, next_actions = node.execute(state.with_is_reentry(True), _env)
-            [x.after_node_execution(node) for x in self.listeners]
+            [x.before_node_execution(node, state) for x in self.listeners]
+            new_state, next_actions = node.execute(next_state, next_env)
+            [x.after_node_execution(node, state) for x in self.listeners]
 
-            return flatten([self._handle_action(action, new_state, env) for action in next_actions])
+            return flatten([self._handle_action(action, new_state, next_env) for action in next_actions])
 
         # Incident Action
         # ***************
