@@ -5,7 +5,6 @@ from arrow_bpmn.__spi__ import CompleteAction
 from arrow_bpmn.__spi__.action import Actions
 from arrow_bpmn.__spi__.execution import Environment
 from arrow_bpmn.__spi__.execution import State
-from arrow_bpmn.parser.xml.xml_element import XMLElement
 
 
 class NoneEndEvent(BpmnNode):
@@ -17,7 +16,7 @@ class NoneEndEvent(BpmnNode):
     <bpmn:endEvent />
     """
 
-    def __init__(self, element: XMLElement):
+    def __init__(self, element: dict):
         super().__init__(element)
 
     def execute(self, state: State, environment: Environment) -> Tuple[State, Actions]:
