@@ -6,7 +6,6 @@ from arrow_bpmn.__spi__.action.event_action import EventAction
 from arrow_bpmn.__spi__.execution import Environment
 from arrow_bpmn.__spi__.execution import State
 from arrow_bpmn.engine.registry.abstract_event_registry import SignalEvent
-from arrow_bpmn.parser.xml.xml_element import XMLElement
 
 
 class SignalIntermediateThrowEvent(BpmnNode):
@@ -14,7 +13,7 @@ class SignalIntermediateThrowEvent(BpmnNode):
     A Signal Intermediate Throwing event sends a signal to an external service.
     """
 
-    def __init__(self, element: XMLElement, signal: str):
+    def __init__(self, element: dict, signal: str):
         super().__init__(element)
         self.signal = signal
 
