@@ -21,7 +21,7 @@ class NoneStartEvent(BpmnNode, EventRegistryAware):
 
     def with_event_registry(self, process_ref: ProcessRef, event_registry: EventRegistry):
         event = NoneEvent(process_ref.group, process_ref.process_id)
-        event_registry.create_subscription(event, NodeRef(process_ref.group, process_ref.process_id, self.id))
+        event_registry.create_subscription(event, NodeRef(process_ref.group, process_ref.process_id, self.id), False)
 
     def __repr__(self):
         return f"NoneStartEvent({self.id})"
