@@ -1,6 +1,6 @@
 from typing import Tuple
 
-from arrow_bpmn.__spi__ import BpmnNode
+from arrow_bpmn.__spi__ import BpmnNode, IncidentAction
 from arrow_bpmn.__spi__ import CompleteAction
 from arrow_bpmn.__spi__.action import ContinueAction, Actions, EventAction
 from arrow_bpmn.__spi__.execution import Environment
@@ -27,8 +27,9 @@ class ScriptTask(BpmnNode):
         try:
             engine = environment.script_factory(state, self.script_format, self.script)
             state[self.var_name] = engine(state.properties)
-        except Exception:
-            return state, [EventAction(self.id, ErrorEvent(environment.group, "script-error"))]
+        except Exception as ex:
+            action = IncidentAction(self.id, "script-error", ex.args[0])
+            return state, [EventAction(self.id, ErrorEvent(environment.group, "script-error")), action]
 
         actions = [ContinueAction(node) for node in environment.get_outgoing_nodes(self.id)]
         return state, [CompleteAction(self.id)] + actions
