@@ -133,7 +133,7 @@ class JsonBpmnParser(BpmnParser):
         _type = element["type"]
         _item = element.get_object("item")
 
-        attributes = self._concat_dicts(_item.as_dict(), self.extension.parse_json(element))
+        attributes = _item.as_dict()
 
         if _type == "BusinessRuleTask":
             return BusinessRuleTask(attributes)
