@@ -69,7 +69,7 @@ class XmlBpmnParser(BpmnParser):
         ie2 = [self._parse_intermediate_throw_event(x, events) for x in process.get_tags("bpmn:intermediateThrowEvent")]
         intermediate_events = ie1 + ie2
 
-        return Process(process.get_attributes(), sequence_flows, associations, tasks, start_events, end_events,
+        return Process(self._parse_attributes(process), sequence_flows, associations, tasks, start_events, end_events,
                        boundary_events, intermediate_events, gateways, events)
 
     def _parse_sequence_flow(self, element: XMLElement):
