@@ -42,7 +42,10 @@ class XMLElement:
 
         return attributes[name] if name in attributes else default_value
 
-    def get_text(self, unescape: bool = False):
+    def get_text(self, unescape: bool = False) -> Optional[str]:
+        if self.element.text is None:
+            return None
+
         if unescape:
             import xml.sax.saxutils as sax
             return sax.unescape(self.element.text.strip())
